@@ -3,6 +3,7 @@
 
 #include <gtk/gtk.h>
 #include <folks/folks.h>
+#include "empathy-contact.h"
 
 G_BEGIN_DECLS
 
@@ -13,13 +14,13 @@ typedef struct _EmpathyRosterContactPriv EmpathyRosterContactPriv;
 struct _EmpathyRosterContactClass
 {
   /*<private>*/
-  GtkAlignmentClass parent_class;
+  GtkListBoxRowClass parent_class;
 };
 
 struct _EmpathyRosterContact
 {
   /*<private>*/
-  GtkAlignment parent;
+  GtkListBoxRow parent;
   EmpathyRosterContactPriv *priv;
 };
 
@@ -52,6 +53,8 @@ GtkWidget * empathy_roster_contact_new (FolksIndividual *individual,
 
 FolksIndividual * empathy_roster_contact_get_individual (EmpathyRosterContact *self);
 
+EmpathyContact * empathy_roster_contact_get_contact (EmpathyRosterContact *self);
+
 const gchar * empathy_roster_contact_get_group (EmpathyRosterContact *self);
 
 gboolean empathy_roster_contact_is_online (EmpathyRosterContact *self);
@@ -62,6 +65,8 @@ void empathy_roster_contact_set_event_icon (EmpathyRosterContact *self,
 GdkPixbuf * empathy_roster_contact_get_avatar_pixbuf (
     EmpathyRosterContact *self);
 
+gint64 empathy_roster_contact_get_most_recent_timestamp (EmpathyRosterContact *contact);
+
 G_END_DECLS
 
 #endif /* #ifndef __EMPATHY_ROSTER_CONTACT_H__*/
