@@ -220,7 +220,7 @@ main (int argc,
   XInitThreads ();
 #endif
 
-  optcontext = g_option_context_new (N_("- Empathy Audio/Video Client"));
+  optcontext = g_option_context_new (N_("— Empathy Audio/Video Client"));
   g_option_context_add_group (optcontext, gst_init_get_option_group ());
   g_option_context_add_group (optcontext, gtk_get_option_group (TRUE));
   g_option_context_add_group (optcontext, cogl_get_option_group ());
@@ -247,7 +247,7 @@ main (int argc,
   g_set_application_name (_("Empathy Audio/Video Client"));
 
   /* Make empathy and empathy-call appear as the same app in gnome-shell */
-  gdk_set_program_class ("Empathy");
+  g_set_prgname ("empathy");
   gtk_window_set_default_icon_name ("empathy");
 
   gtk_settings = gtk_settings_get_default ();
