@@ -1695,7 +1695,7 @@ debug_window_send_to_pastebin (EmpathyDebugWindow *self,
       "&api_paste_name=%s&api_paste_format=text&api_option=paste",
       api_dev_key, api_paste_code, api_paste_name);
 
-  session = soup_session_async_new ();
+  session = soup_session_new ();
 
   msg = soup_message_new ("POST", "http://pastebin.com/api/api_post.php");
   soup_message_set_request (msg,
@@ -1992,9 +1992,9 @@ am_prepared_cb (GObject *am,
   gtk_info_bar_set_message_type (GTK_INFO_BAR (infobar), GTK_MESSAGE_INFO);
 
   label = gtk_label_new (
-        _("Even if they don't display passwords, logs can contain sensitive "
+        _("Even if they don’t display passwords, logs can contain sensitive "
           "information such as your list of contacts or the messages you "
-          "recently sent or received.\nIf you don't want to see such "
+          "recently sent or received.\nIf you don’t want to see such "
           "information available in a public bug report, you "
           "can choose to limit the visibility of your bug to "
           "Empathy developers when reporting it by displaying "
