@@ -78,7 +78,7 @@ local_cmdline (GApplication *app,
       { NULL }
   };
 
-  optcontext = g_option_context_new (N_("- Empathy Debugger"));
+  optcontext = g_option_context_new (N_("— Empathy Debugger"));
   g_option_context_add_group (optcontext, gtk_get_option_group (FALSE));
   g_option_context_add_main_entries (optcontext, options, GETTEXT_PACKAGE);
   g_option_context_set_translation_domain (optcontext, GETTEXT_PACKAGE);
@@ -141,7 +141,7 @@ main (int argc,
   g_set_application_name (_("Empathy Debugger"));
 
   /* Make empathy and empathy-debugger appear as the same app in gnome-shell */
-  gdk_set_program_class ("Empathy");
+  g_set_prgname ("empathy");
   gtk_window_set_default_icon_name ("empathy");
 
   retval = g_application_run (G_APPLICATION (app), argc, argv);
