@@ -31,6 +31,7 @@
 #include "empathy-ft-manager.h"
 
 #include <glib/gi18n.h>
+#include <tp-account-widgets/tpaw-builder.h>
 
 #include "empathy-geometry.h"
 #include "empathy-ui-utils.h"
@@ -90,7 +91,7 @@ ft_manager_format_interval (guint interval)
 
   if (hours > 0)
     /* Translators: time left, when it is more than one hour */
-    return g_strdup_printf (_("%u:%02u.%02u"), hours, mins, secs);
+    return g_strdup_printf (_("%u∶%02u.%02u"), hours, mins, secs);
   else
     /* Translators: time left, when is is less than one hour */
     return g_strdup_printf (_("%02u.%02u"), mins, secs);
@@ -261,9 +262,9 @@ ft_manager_format_progress_bytes_and_percentage (guint64 current,
   if (speed > 0)
     speed_str = g_format_size ((goffset) speed);
 
-  /* translators: first %s is the currently processed size, second %s is
-   * the total file size */
   retval = speed_str ?
+    /* translators: first %s is the currently processed size, second %s is
+     * the total file size */
     g_strdup_printf (_("%s of %s at %s/s"), current_str, total_str, speed_str) :
     g_strdup_printf (_("%s of %s"), current_str, total_str);
 
@@ -296,10 +297,10 @@ ft_manager_format_contact_info (EmpathyFTHandler *handler)
 
   if (incoming)
     /* translators: first %s is filename, second %s is the contact name */
-    first_line_format = _("Receiving \"%s\" from %s");
+    first_line_format = _("Receiving “%s” from %s");
   else
     /* translators: first %s is filename, second %s is the contact name */
-    first_line_format = _("Sending \"%s\" to %s");
+    first_line_format = _("Sending “%s” to %s");
 
   retval = g_strdup_printf (first_line_format, filename, contact_name);
 
@@ -329,15 +330,15 @@ ft_manager_format_error_message (EmpathyFTHandler *handler,
     if (filename && contact_name)
       /* translators: first %s is filename, second %s
        * is the contact name */
-      first_line = g_strdup_printf (_("Error receiving \"%s\" from %s"), filename,
+      first_line = g_strdup_printf (_("Error receiving “%s” from %s"), filename,
           contact_name);
     else
       first_line = g_strdup (_("Error receiving a file"));
   else
-    /* translators: first %s is filename, second %s
-     * is the contact name */
     if (filename && contact_name)
-      first_line = g_strdup_printf (_("Error sending \"%s\" to %s"), filename,
+      /* translators: first %s is filename, second %s
+       * is the contact name */
+      first_line = g_strdup_printf (_("Error sending “%s” to %s"), filename,
           contact_name);
     else
       first_line = g_strdup (_("Error sending a file"));
@@ -479,12 +480,12 @@ do_real_transfer_done (EmpathyFTManager *manager,
   if (incoming)
     /* translators: first %s is filename, second %s
      * is the contact name */
-    first_line = g_strdup_printf (_("\"%s\" received from %s"), filename,
+    first_line = g_strdup_printf (_("“%s” received from %s"), filename,
         contact_name);
   else
     /* translators: first %s is filename, second %s
      * is the contact name */
-    first_line = g_strdup_printf (_("\"%s\" sent to %s"), filename,
+    first_line = g_strdup_printf (_("“%s” sent to %s"), filename,
         contact_name);
 
   second_line = g_strdup (_("File transfer completed"));
@@ -606,7 +607,7 @@ ft_handler_hashing_done_cb (EmpathyFTHandler *handler,
   g_return_if_fail (row_ref != NULL);
 
   first_line = ft_manager_format_contact_info (handler);
-  second_line = g_strdup (_("Waiting for the other participant's response"));
+  second_line = g_strdup (_("Waiting for the other participant’s response"));
   message = g_strdup_printf ("%s\n%s", first_line, second_line);
 
   ft_manager_update_handler_message (manager, row_ref, message);
@@ -632,10 +633,10 @@ ft_handler_hashing_progress_cb (EmpathyFTHandler *handler,
   g_return_if_fail (row_ref != NULL);
 
   if (empathy_ft_handler_is_incoming (handler))
-      first_line = g_strdup_printf (_("Checking integrity of \"%s\""),
+      first_line = g_strdup_printf (_("Checking integrity of “%s”"),
           empathy_ft_handler_get_filename (handler));
   else
-      first_line =  g_strdup_printf (_("Hashing \"%s\""),
+      first_line =  g_strdup_printf (_("Hashing “%s”"),
           empathy_ft_handler_get_filename (handler));
 
   second_line = ft_manager_format_progress_bytes_and_percentage
@@ -670,10 +671,10 @@ ft_handler_hashing_started_cb (EmpathyFTHandler *handler,
   first_line = ft_manager_format_contact_info (handler);
 
   if (empathy_ft_handler_is_incoming (handler))
-      second_line = g_strdup_printf (_("Checking integrity of \"%s\""),
+      second_line = g_strdup_printf (_("Checking integrity of “%s”"),
           empathy_ft_handler_get_filename (handler));
   else
-      second_line = g_strdup_printf (_("Hashing \"%s\""),
+      second_line = g_strdup_printf (_("Hashing “%s”"),
           empathy_ft_handler_get_filename (handler));
 
   message = g_strdup_printf ("%s\n%s", first_line, second_line);
@@ -770,7 +771,7 @@ ft_manager_add_handler_to_list (EmpathyFTManager *manager,
   if (empathy_ft_handler_is_incoming (handler) ||
       !empathy_ft_handler_get_use_hash (handler)) {
     first_line = ft_manager_format_contact_info (handler);
-    second_line = _("Waiting for the other participant's response");
+    second_line = _("Waiting for the other participant’s response");
     message = g_strdup_printf ("%s\n%s", first_line, second_line);
 
     ft_manager_update_handler_message (manager, row_ref, message);
@@ -970,7 +971,7 @@ ft_manager_build_ui (EmpathyFTManager *manager)
   EmpathyFTManagerPriv *priv = GET_PRIV (manager);
 
   filename = empathy_file_lookup ("empathy-ft-manager.ui", "src");
-  gui = empathy_builder_get_file (filename,
+  gui = tpaw_builder_get_file (filename,
       "ft_manager_dialog", &priv->window,
       "ft_list", &priv->treeview,
       "clear_button", &priv->clear_button,
@@ -979,14 +980,14 @@ ft_manager_build_ui (EmpathyFTManager *manager)
       NULL);
   g_free (filename);
 
-  empathy_builder_connect (gui, manager,
+  tpaw_builder_connect (gui, manager,
       "ft_manager_dialog", "destroy", ft_manager_destroy_cb,
       "ft_manager_dialog", "response", ft_manager_response_cb,
       "ft_manager_dialog", "delete-event", ft_manager_delete_event_cb,
       "ft_manager_dialog", "key-press-event", ft_manager_key_press_event_cb,
       NULL);
 
-  empathy_builder_unref_and_keep_widget (gui, priv->window);
+  tpaw_builder_unref_and_keep_widget (gui, priv->window);
 
   /* Window geometry. */
   empathy_geometry_bind (GTK_WINDOW (priv->window), "ft-manager");
