@@ -25,6 +25,8 @@
 #include "empathy-new-chatroom-dialog.h"
 
 #include <glib/gi18n.h>
+#include <tp-account-widgets/tpaw-builder.h>
+#include <tp-account-widgets/tpaw-utils.h>
 
 #include "empathy-account-chooser.h"
 #include "empathy-gsettings.h"
@@ -113,7 +115,7 @@ new_chatroom_dialog_join (EmpathyNewChatroomDialog *self)
   account_chooser = EMPATHY_ACCOUNT_CHOOSER (self->priv->account_chooser);
   account = empathy_account_chooser_get_account (account_chooser);
 
-  if (!EMP_STR_EMPTY (server))
+  if (!TPAW_STR_EMPTY (server))
     room_name = g_strconcat (room, "@", server, NULL);
   else
     room_name = g_strdup (room);
@@ -288,7 +290,7 @@ update_join_button_sensitivity (EmpathyNewChatroomDialog *self)
 
   room = gtk_entry_get_text (GTK_ENTRY (self->priv->entry_room));
   protocol = tp_account_get_protocol_name (self->priv->account);
-  if (EMP_STR_EMPTY (room))
+  if (TPAW_STR_EMPTY (room))
     goto out;
 
   if (!tp_strdiff (protocol, "irc") &&
@@ -429,9 +431,9 @@ new_chatroom_dialog_got_room_cb (TpRoomList *room_list,
         room, NULL));
   tmp = g_strdup_printf ("<b>%s</b>", tp_room_info_get_name (room));
 
-  /* Translators: Room/Join's roomlist tooltip. Parameters are a channel name,
-  yes/no, yes/no and a number. */
   tooltip = g_strdup_printf (
+      /* Translators: Room/Join's roomlist tooltip. Parameters are a channel name,
+      yes/no, yes/no and a number. */
       _("%s\nInvite required: %s\nPassword required: %s\nMembers: %s"),
       tmp,
       tp_room_info_get_invite_only (room, NULL) ? _("Yes") : _("No"),
@@ -747,7 +749,7 @@ empathy_new_chatroom_dialog_init (EmpathyNewChatroomDialog *self)
       EMPATHY_TYPE_NEW_CHATROOM_DIALOG, EmpathyNewChatroomDialogPriv);
 
   filename = empathy_file_lookup ("empathy-new-chatroom-dialog.ui", "src");
-  gui = empathy_builder_get_file (filename,
+  gui = tpaw_builder_get_file (filename,
       "vbox_new_chatroom", &vbox,
       "table_grid", &self->priv->table_grid,
       "label_account", &self->priv->label_account,
@@ -763,7 +765,7 @@ empathy_new_chatroom_dialog_init (EmpathyNewChatroomDialog *self)
       NULL);
   g_free (filename);
 
-  empathy_builder_connect (gui, self,
+  tpaw_builder_connect (gui, self,
       "entry_server", "changed", new_chatroom_dialog_entry_changed_cb,
       "entry_server", "activate", new_chatroom_dialog_entry_server_activate_cb,
       "entry_server", "focus-out-event",
