@@ -601,8 +601,18 @@ preferences_preview_theme_changed_cb (EmpathyThemeManager *manager,
 		gtk_widget_destroy (GTK_WIDGET (priv->chat_theme_preview));
 	}
 	priv->chat_theme_preview = empathy_theme_manager_create_view (manager);
-	gtk_container_add (GTK_CONTAINER (priv->sw_chat_theme_preview),
-			   GTK_WIDGET (priv->chat_theme_preview));
+	if (GTK_IS_SCROLLABLE (priv->chat_theme_preview))
+	  {
+	    gtk_container_add (GTK_CONTAINER (priv->sw_chat_theme_preview),
+			       GTK_WIDGET (priv->chat_theme_preview));
+	  }
+	else
+	  {
+	    gtk_widget_hide (priv->sw_chat_theme_preview);
+	    gtk_box_pack_start (GTK_BOX (priv->vbox_chat_theme),
+				GTK_WIDGET (priv->chat_theme_preview),
+				TRUE, TRUE, 0);
+	  }
 	gtk_widget_show (GTK_WIDGET (priv->chat_theme_preview));
 
 	/* FIXME: It is ugly to add a fake conversation like that.
@@ -640,7 +650,7 @@ preferences_preview_theme_changed_cb (EmpathyThemeManager *manager,
 		juliet, romeo, _("Or if thou wilt not, be but sworn my love"), FALSE);
 	preferences_preview_theme_append_message (priv->chat_theme_preview,
 		/* translators: Quote from Romeo & Julier, for chat theme preview */
-		juliet, romeo, _("And I'll no longer be a Capulet."), FALSE);
+		juliet, romeo, _("And I’ll no longer be a Capulet."), FALSE);
 	preferences_preview_theme_append_message (priv->chat_theme_preview,
 		/* translators: Quote from Romeo & Julier, for chat theme preview */
 		romeo, juliet, _("Shall I hear more, or shall I speak at this?"), FALSE);
