@@ -32,6 +32,7 @@
 #include "empathy-accounts-dialog.h"
 #include "empathy-call-observer.h"
 #include "empathy-chat-manager.h"
+#include "empathy-chat-window.h"
 #include "empathy-chatroom-manager.h"
 #include "empathy-chatrooms-window.h"
 #include "empathy-client-factory.h"
@@ -55,6 +56,8 @@
 #include "empathy-roster-model-manager.h"
 #include "empathy-roster-view.h"
 #include "empathy-status-presets.h"
+#include "empathy-theme-manager.h"
+#include "empathy-theme-manager.h"
 #include "empathy-ui-utils.h"
 #include "empathy-utils.h"
 
@@ -90,6 +93,8 @@ G_DEFINE_TYPE (EmpathyRosterWindow, empathy_roster_window, GTK_TYPE_APPLICATION_
 struct _EmpathyRosterWindowPriv {
   EmpathyRosterView *view;
   TpAccountManager *account_manager;
+  EmpathyChatManager *chat_manager;
+  EmpathyThemeManager *theme_manager;
   EmpathyChatroomManager *chatroom_manager;
   EmpathyEventManager *event_manager;
   EmpathySoundManager *sound_mgr;
@@ -111,11 +116,12 @@ struct _EmpathyRosterWindowPriv {
   GtkWidget *notebook;
   GtkWidget *no_entry_label;
   GtkWidget *button_account_settings;
-  GtkWidget *button_online;
+  //GtkWidget *button_online;
   GtkWidget *button_show_offline;
   GtkWidget *button_add_contact;
   GtkWidget *spinner_loading;
   GtkWidget *tooltip_widget;
+  GtkWidget *chat_window;
 
   GMenu *menumodel;
   GMenu *rooms_section;
@@ -202,7 +208,7 @@ roster_window_auth_display (EmpathyRosterWindow *self,
   gtk_info_bar_set_message_type (GTK_INFO_BAR (info_bar), GTK_MESSAGE_QUESTION);
 
   gtk_widget_set_no_show_all (info_bar, TRUE);
-  gtk_box_pack_start (GTK_BOX (self->priv->auth_vbox), info_bar, FALSE, TRUE, 0);
+  gtk_container_add (GTK_CONTAINER (self->priv->auth_vbox), info_bar);
   gtk_widget_show (info_bar);
 
   icon_name = tp_account_get_icon_name (account);
@@ -222,8 +228,8 @@ roster_window_auth_display (EmpathyRosterWindow *self,
   g_free (str);
 
   content_area = gtk_info_bar_get_content_area (GTK_INFO_BAR (info_bar));
-  gtk_box_pack_start (GTK_BOX (content_area), image, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (content_area), label, TRUE, TRUE, 0);
+  gtk_container_add (GTK_CONTAINER (content_area), image);
+  gtk_container_add (GTK_CONTAINER (content_area), label);
 
   image = gtk_image_new_from_stock (GTK_STOCK_ADD, GTK_ICON_SIZE_BUTTON);
   add_button = gtk_button_new ();
@@ -242,7 +248,7 @@ roster_window_auth_display (EmpathyRosterWindow *self,
   gtk_widget_show (action_grid);
 
   action_area = gtk_info_bar_get_action_area (GTK_INFO_BAR (info_bar));
-  gtk_box_pack_start (GTK_BOX (action_area), action_grid, FALSE, FALSE, 0);
+  gtk_container_add (GTK_CONTAINER (action_area), action_grid);
 
   gtk_grid_attach (GTK_GRID (action_grid), add_button, 0, 0, 1, 1);
   gtk_grid_attach (GTK_GRID (action_grid), close_button, 1, 0, 1, 1);
@@ -381,7 +387,7 @@ button_account_settings_clicked_cb (GtkButton *button,
   empathy_accounts_dialog_show_application (gdk_screen_get_default (),
       NULL, FALSE, FALSE);
 }
-
+/*
 static void
 button_online_clicked_cb (GtkButton *button,
     EmpathyRosterWindow *self)
@@ -394,7 +400,7 @@ button_online_clicked_cb (GtkButton *button,
       TP_CONNECTION_PRESENCE_TYPE_AVAILABLE);
 
   g_object_unref (mgr);
-}
+}*/
 
 static void
 button_show_offline_clicked_cb (GtkButton *button,
@@ -472,8 +478,8 @@ display_page_message (EmpathyRosterWindow *self,
       (flags & PAGE_MESSAGE_FLAG_ACCOUNTS) != 0);
   gtk_widget_set_visible (self->priv->spinner_loading,
       (flags & PAGE_MESSAGE_FLAG_SPINNER) != 0);
-  gtk_widget_set_visible (self->priv->button_online,
-      (flags & PAGE_MESSAGE_FLAG_ONLINE) != 0);
+//  gtk_widget_set_visible (self->priv->button_online,
+//      (flags & PAGE_MESSAGE_FLAG_ONLINE) != 0);
   gtk_widget_set_visible (self->priv->button_show_offline,
       (flags & PAGE_MESSAGE_FLAG_SHOW_OFFLINE) != 0);
   gtk_widget_set_visible (self->priv->button_add_contact,
@@ -602,7 +608,7 @@ roster_window_error_create_info_bar (EmpathyRosterWindow *self,
   gtk_info_bar_set_message_type (GTK_INFO_BAR (info_bar), message_type);
 
   gtk_widget_set_no_show_all (info_bar, TRUE);
-  gtk_box_pack_start (GTK_BOX (self->priv->errors_vbox), info_bar, FALSE, TRUE, 0);
+  gtk_container_add (GTK_CONTAINER (self->priv->errors_vbox), info_bar);
   gtk_widget_show (info_bar);
 
   icon_name = tp_account_get_icon_name (account);
@@ -617,8 +623,8 @@ roster_window_error_create_info_bar (EmpathyRosterWindow *self,
   gtk_widget_show (label);
 
   content_area = gtk_info_bar_get_content_area (GTK_INFO_BAR (info_bar));
-  gtk_box_pack_start (GTK_BOX (content_area), image, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (content_area), label, TRUE, TRUE, 0);
+  gtk_container_add (GTK_CONTAINER (content_area), image);
+  gtk_container_add (GTK_CONTAINER (content_area), label);
 
   action_area = gtk_info_bar_get_action_area (GTK_INFO_BAR (info_bar));
   gtk_orientable_set_orientation (GTK_ORIENTABLE (action_area),
@@ -789,7 +795,7 @@ roster_window_update_status (EmpathyRosterWindow *self)
   for (l = self->priv->actions_connected; l; l = l->next)
     g_simple_action_set_enabled (l->data, connected);
 
-  action = g_action_map_lookup_action (G_ACTION_MAP (self), "chat_add_contact");
+  action = g_action_map_lookup_action (G_ACTION_MAP (self), "chat-add-contact");
   if (!can_add_contact (self))
     g_simple_action_set_enabled (G_SIMPLE_ACTION (action), FALSE);
 }
@@ -873,7 +879,7 @@ roster_window_setup_balance (EmpathyRosterWindow *self,
 
   /* protocol icon */
   image = gtk_image_new ();
-  gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, TRUE, 0);
+  gtk_container_add (GTK_CONTAINER (hbox), image);
   g_object_bind_property (account, "icon-name", image, "icon-name",
       G_BINDING_SYNC_CREATE);
 
@@ -881,14 +887,14 @@ roster_window_setup_balance (EmpathyRosterWindow *self,
   label = gtk_label_new ("");
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
-  gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
+  gtk_container_add (GTK_CONTAINER (hbox), label);
   g_object_bind_property (account, "display-name", label, "label",
       G_BINDING_SYNC_CREATE);
 
   /* balance label */
   label = gtk_label_new ("");
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, TRUE, 0);
+  gtk_container_add (GTK_CONTAINER (hbox), label);
 
   /* top up button */
   uri = tp_connection_get_balance_uri (conn);
@@ -903,7 +909,7 @@ roster_window_setup_balance (EmpathyRosterWindow *self,
             GTK_ICON_SIZE_SMALL_TOOLBAR));
       gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
       gtk_widget_set_tooltip_text (button, _("Top up account"));
-      gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, TRUE, 0);
+      gtk_container_add (GTK_CONTAINER (hbox), button);
 
       g_signal_connect_data (button, "clicked",
           G_CALLBACK (empathy_url_show),
@@ -911,7 +917,7 @@ roster_window_setup_balance (EmpathyRosterWindow *self,
           0);
     }
 
-  gtk_box_pack_start (GTK_BOX (self->priv->balance_vbox), hbox, FALSE, TRUE, 0);
+  gtk_container_add (GTK_CONTAINER (self->priv->balance_vbox), hbox);
   gtk_widget_show_all (hbox);
 
   g_object_set_data (G_OBJECT (account), "balance-money-label", label);
@@ -1033,6 +1039,8 @@ empathy_roster_window_finalize (GObject *window)
 
   g_object_unref (self->priv->call_observer);
   g_object_unref (self->priv->event_manager);
+  g_object_unref (self->priv->chat_manager);
+  g_object_unref (self->priv->theme_manager);
   g_object_unref (self->priv->chatroom_manager);
 
   g_object_unref (self->priv->gsettings_ui);
@@ -1540,6 +1548,25 @@ roster_window_help_contents_cb (GSimpleAction *action,
   empathy_url_show (GTK_WIDGET (self), "help:empathy");
 }
 
+static void
+next_tab_cb (GSimpleAction *action,
+    GVariant *parameter,
+    gpointer user_data)
+{
+  EmpathyRosterWindow *self = user_data;
+  empathy_chat_window_next_tab (EMPATHY_CHAT_WINDOW (self->priv->chat_window));
+}
+
+static void
+prev_tab_cb (GSimpleAction *action,
+    GVariant *parameter,
+    gpointer user_data)
+{
+  EmpathyRosterWindow *self = user_data;
+  empathy_chat_window_prev_tab (EMPATHY_CHAT_WINDOW (self->priv->chat_window));
+}
+
+
 static gboolean
 roster_window_throbber_button_press_event_cb (GtkWidget *throbber,
     GdkEventButton *event,
@@ -1708,9 +1735,10 @@ set_notebook_page (EmpathyRosterWindow *self)
 
   if (presence == TP_CONNECTION_PRESENCE_TYPE_OFFLINE)
     {
-      display_page_message (self,
-          _("Change your presence to see contacts here"),
-          PAGE_MESSAGE_FLAG_ONLINE);
+// This message shows up always. WTF telepathy?
+//      display_page_message (self,
+//          _("Change your presence to see contacts here"),
+//          PAGE_MESSAGE_FLAG_ONLINE);
       goto out;
     }
 
@@ -1725,7 +1753,7 @@ set_notebook_page (EmpathyRosterWindow *self)
         {
           if (g_settings_get_boolean (self->priv->gsettings_ui,
                 EMPATHY_PREFS_UI_SHOW_OFFLINE))
-            display_page_message (self, _("You haven't added any contacts yet"),
+            display_page_message (self, _("You haven’t added any contacts yet"),
                 PAGE_MESSAGE_FLAG_ADD_CONTACT);
           else
             display_page_message (self, _("No online contacts"),
@@ -1759,13 +1787,13 @@ roster_window_connection_items_setup (EmpathyRosterWindow *self)
 {
   guint i;
   const gchar *actions_connected[] = {
-      "room_join_new",
-      "room_join_favorites",
-      "chat_new_message",
-      "chat_new_call",
-      "chat_search_contacts",
-      "chat_add_contact",
-      "edit_blocked_contacts",
+      "room-join-new",
+      "room-join-favorites",
+      "chat-new-message",
+      "chat-new-call",
+      "chat-search-contacts",
+      "chat-add-contact",
+      "edit-blocked-contacts",
   };
 
   for (i = 0; i < G_N_ELEMENTS (actions_connected); i++)
@@ -1876,28 +1904,35 @@ empathy_roster_window_constructor (GType type,
 }
 
 static GActionEntry menubar_entries[] = {
-  { "chat_new_message", roster_window_chat_new_message_cb, NULL, NULL, NULL },
-  { "chat_new_call", roster_window_chat_new_call_cb, NULL, NULL, NULL },
-  { "chat_add_contact", roster_window_chat_add_contact_cb, NULL, NULL, NULL },
-  { "chat_search_contacts", roster_window_chat_search_contacts_cb, NULL, NULL, NULL },
-  { "chat_quit", roster_window_chat_quit_cb, NULL, NULL, NULL },
+  {"chat-new-message", roster_window_chat_new_message_cb},
+  {"chat-new-call", roster_window_chat_new_call_cb},
+  {"chat-add-contact", roster_window_chat_add_contact_cb},
+  {"chat-search-contacts", roster_window_chat_search_contacts_cb},
+  {"chat-quit", roster_window_chat_quit_cb},
 
-  { "edit_accounts", roster_window_edit_accounts_cb, NULL, NULL, NULL },
-  { "edit_blocked_contacts", roster_window_edit_blocked_contacts_cb, NULL, NULL, NULL },
-  { "edit_preferences", roster_window_edit_preferences_cb, NULL, NULL, NULL },
+  {"edit-accounts", roster_window_edit_accounts_cb},
+  {"edit-blocked-contacts", roster_window_edit_blocked_contacts_cb},
+  {"edit-preferences", roster_window_edit_preferences_cb},
 
-  { "view_history", roster_window_view_history_cb, NULL, NULL, NULL },
-  { "view_show_ft_manager", roster_window_view_show_ft_manager, NULL, NULL, NULL },
+  {"view-history", roster_window_view_history_cb},
+  {"view-show-ft-manager", roster_window_view_show_ft_manager},
 
-  { "room_join_new", roster_window_room_join_new_cb, NULL, NULL, NULL },
-  { "room_join_favorites", roster_window_room_join_favorites_cb, NULL, NULL, NULL },
-  { "join", roster_window_join_chatroom_menu_activate_cb, "(ss)", NULL, NULL },
-  { "room_manage_favorites", roster_window_room_manage_favorites_cb, NULL, NULL, NULL },
+  {"room-join-new", roster_window_room_join_new_cb},
+  {"room-join-favorites", roster_window_room_join_favorites_cb},
+  {"join", roster_window_join_chatroom_menu_activate_cb, "(ss)"},
+  {"room-manage-favorites", roster_window_room_manage_favorites_cb},
 
-  { "help_contents", roster_window_help_contents_cb, NULL, NULL, NULL },
-  { "help_about", roster_window_help_about_cb, NULL, NULL, NULL },
+  {"help-contents", roster_window_help_contents_cb},
+  {"help-about", roster_window_help_about_cb},
 };
 
+static GActionEntry app_entries[] =
+{
+  { "tab-next", next_tab_cb },
+  { "tab-prev", prev_tab_cb }
+};
+
+
 static void
 empathy_roster_window_set_property (GObject *object,
     guint property_id,
@@ -2271,21 +2306,16 @@ roster_window_most_available_presence_changed_cb (TpAccountManager *manager,
   set_notebook_page (self);
 }
 
-static void
-show_offline_changed_cb (GSettings *settings,
-    const gchar *key,
-    EmpathyRosterWindow *self)
-{
-  set_notebook_page (self);
-}
-
 static void
 empathy_roster_window_init (EmpathyRosterWindow *self)
 {
   GtkBuilder *gui;
   GtkWidget *sw;
   gchar *filename;
-  GtkWidget *search_vbox;
+  GtkWidget *header_bar;
+  GtkWidget *new_conversation_button;
+  GtkWidget *image;
+  GtkWidget *chat_vbox;
   guint i;
   EmpathyRosterModel *model;
 
@@ -2302,30 +2332,40 @@ empathy_roster_window_init (EmpathyRosterWindow *self)
   gtk_window_set_role (GTK_WINDOW (self), "contact_list");
   gtk_window_set_default_size (GTK_WINDOW (self), 225, 325);
 
-  /* don't finalize the widget on delete-event, just hide it */
-  g_signal_connect (self, "delete-event",
-    G_CALLBACK (gtk_widget_hide_on_delete), NULL);
-
   /* Set up interface */
   filename = empathy_file_lookup ("empathy-roster-window.ui", "src");
   gui = tpaw_builder_get_file (filename,
       "main_vbox", &self->priv->main_vbox,
+      "chat_vbox", &chat_vbox,
       "balance_vbox", &self->priv->balance_vbox,
       "errors_vbox", &self->priv->errors_vbox,
       "auth_vbox", &self->priv->auth_vbox,
-      "search_vbox", &search_vbox,
       "presence_toolbar", &self->priv->presence_toolbar,
       "notebook", &self->priv->notebook,
       "no_entry_label", &self->priv->no_entry_label,
       "roster_scrolledwindow", &sw,
       "button_account_settings", &self->priv->button_account_settings,
-      "button_online", &self->priv->button_online,
+//      "button_online", &self->priv->button_online,
       "button_show_offline", &self->priv->button_show_offline,
       "button_add_contact", &self->priv->button_add_contact,
       "spinner_loading", &self->priv->spinner_loading,
       NULL);
   g_free (filename);
 
+  header_bar = gtk_header_bar_new ();
+  gtk_header_bar_set_title (GTK_HEADER_BAR(header_bar), _("Conversations"));
+  gtk_header_bar_set_show_close_button (GTK_HEADER_BAR(header_bar), TRUE);
+
+  image = gtk_image_new_from_icon_name ("list-add-symbolic", GTK_ICON_SIZE_BUTTON);
+  new_conversation_button = gtk_button_new ();
+  g_signal_connect (new_conversation_button, "clicked",
+      G_CALLBACK (roster_window_chat_new_message_cb), self);
+  gtk_button_set_image (GTK_BUTTON (new_conversation_button), image);
+  gtk_widget_set_tooltip_text (new_conversation_button, _("New Conversation"));
+  gtk_window_set_titlebar (GTK_WINDOW (self), header_bar);
+  gtk_container_add (GTK_CONTAINER (header_bar), new_conversation_button);
+  gtk_widget_show_all (header_bar);
+
   gtk_container_add (GTK_CONTAINER (self), self->priv->main_vbox);
   gtk_widget_show (self->priv->main_vbox);
 
@@ -2347,6 +2387,10 @@ empathy_roster_window_init (EmpathyRosterWindow *self)
   self->priv->status_changed_handlers = g_hash_table_new_full (g_direct_hash,
       g_direct_equal, NULL, NULL);
 
+  /* set up accelerators */
+  g_action_map_add_action_entries (G_ACTION_MAP (self),
+      app_entries, G_N_ELEMENTS (app_entries), self);
+
   /* set up menus */
   g_action_map_add_action_entries (G_ACTION_MAP (self),
       menubar_entries, G_N_ELEMENTS (menubar_entries), self);
@@ -2374,9 +2418,7 @@ empathy_roster_window_init (EmpathyRosterWindow *self)
   /* Set up presence chooser */
   self->priv->presence_chooser = empathy_presence_chooser_new ();
   gtk_widget_show (self->priv->presence_chooser);
-  gtk_box_pack_start (GTK_BOX (self->priv->presence_toolbar),
-      self->priv->presence_chooser,
-      TRUE, TRUE, 0);
+  gtk_container_add (GTK_CONTAINER (self->priv->presence_toolbar), self->priv->presence_chooser);
 
   /* Set up the throbber */
   self->priv->throbber = gtk_spinner_new ();
@@ -2385,9 +2427,7 @@ empathy_roster_window_init (EmpathyRosterWindow *self)
   g_signal_connect (self->priv->throbber, "button-press-event",
     G_CALLBACK (roster_window_throbber_button_press_event_cb),
     self);
-  gtk_box_pack_start (GTK_BOX (self->priv->presence_toolbar),
-      self->priv->throbber,
-      FALSE, TRUE, 0);
+  gtk_container_add (GTK_CONTAINER (self->priv->presence_toolbar), self->priv->throbber);
 
   self->priv->individual_manager = empathy_individual_manager_dup_singleton ();
 
@@ -2399,6 +2439,7 @@ empathy_roster_window_init (EmpathyRosterWindow *self)
   self->priv->view = EMPATHY_ROSTER_VIEW (
       empathy_roster_view_new (model));
 
+
   g_object_unref (model);
 
   gtk_widget_show (GTK_WIDGET (self->priv->view));
@@ -2437,8 +2478,6 @@ empathy_roster_window_init (EmpathyRosterWindow *self)
       GTK_WIDGET (self->priv->view));
   empathy_roster_view_set_live_search (self->priv->view,
       TPAW_LIVE_SEARCH (self->priv->search_bar));
-  gtk_box_pack_start (GTK_BOX (search_vbox), self->priv->search_bar,
-      FALSE, TRUE, 0);
 
   g_signal_connect_swapped (self, "map",
       G_CALLBACK (gtk_widget_grab_focus), self->priv->view);
@@ -2446,13 +2485,20 @@ empathy_roster_window_init (EmpathyRosterWindow *self)
   /* Load user-defined accelerators. */
   roster_window_accels_load ();
 
-  gtk_window_set_default_size (GTK_WINDOW (self), -1, 600);
+  gtk_window_set_default_size (GTK_WINDOW (self), 900, 600);
   /* Set window size. */
   empathy_geometry_bind (GTK_WINDOW (self), GEOMETRY_NAME);
 
+  self->priv->chat_window = GTK_WIDGET (empathy_chat_window_new ());
+  gtk_widget_show (GTK_WIDGET (self->priv->chat_window) );
+  gtk_container_add (GTK_CONTAINER (chat_vbox), self->priv->chat_window);
+
   /* Enable event handling */
   self->priv->call_observer = empathy_call_observer_dup_singleton ();
   self->priv->event_manager = empathy_event_manager_dup_singleton ();
+  self->priv->chat_manager = empathy_chat_manager_dup_singleton ();
+
+  self->priv->theme_manager = empathy_theme_manager_dup_singleton ();
 
   tp_g_signal_connect_object (self->priv->event_manager, "event-added",
       G_CALLBACK (roster_window_event_added_cb), self, 0);
@@ -2469,23 +2515,19 @@ empathy_roster_window_init (EmpathyRosterWindow *self)
       "most-available-presence-changed",
       G_CALLBACK (roster_window_most_available_presence_changed_cb), self);
 
-  g_settings_bind (self->priv->gsettings_ui, EMPATHY_PREFS_UI_SHOW_OFFLINE,
-      self->priv->view, "show-offline",
-      G_SETTINGS_BIND_GET);
-  tp_g_signal_connect_object (self->priv->gsettings_ui,
-      "changed::" EMPATHY_PREFS_UI_SHOW_OFFLINE,
-      G_CALLBACK (show_offline_changed_cb), self, 0);
-  g_settings_bind (self->priv->gsettings_ui, EMPATHY_PREFS_UI_SHOW_GROUPS,
-      self->priv->view, "show-groups",
-      G_SETTINGS_BIND_GET);
+  g_object_set (G_OBJECT (self->priv->view),
+                  "show-offline", TRUE,
+                  "show-groups", FALSE,
+                  NULL);
+
   g_settings_bind (self->priv->gsettings_ui, "show-balance-in-roster",
       self->priv->balance_vbox, "visible",
       G_SETTINGS_BIND_GET);
 
   g_signal_connect (self->priv->button_account_settings, "clicked",
       G_CALLBACK (button_account_settings_clicked_cb), self);
-  g_signal_connect (self->priv->button_online, "clicked",
-      G_CALLBACK (button_online_clicked_cb), self);
+//  g_signal_connect (self->priv->button_online, "clicked",
+//      G_CALLBACK (button_online_clicked_cb), self);
   g_signal_connect (self->priv->button_show_offline, "clicked",
       G_CALLBACK (button_show_offline_clicked_cb), self);
   g_signal_connect (self->priv->button_add_contact, "clicked",
