@@ -116,14 +116,8 @@ empathy_app_dispose (GObject *object)
   void (*dispose) (GObject *) =
     G_OBJECT_CLASS (empathy_app_parent_class)->dispose;
 
-  /* Only set our presence to offline when exiting if GNOME Shell is not
-   * running */
-  if (self->presence_mgr != NULL &&
-      !self->shell_running)
-    {
-      empathy_presence_manager_set_state (self->presence_mgr,
-          TP_CONNECTION_PRESENCE_TYPE_OFFLINE);
-    }
+  empathy_presence_manager_set_state (self->presence_mgr,
+      TP_CONNECTION_PRESENCE_TYPE_OFFLINE);
 
 #ifdef ENABLE_DEBUG
   tp_clear_object (&self->debug_sender);
@@ -223,6 +217,7 @@ empathy_presence_manager_set_auto_away_cb (GSettings *gsettings,
 }
 
 #define GNOME_SHELL_BUS_NAME "org.gnome.Shell"
+#define GNOME_FLASHBACK_BUS_NAME "org.gnome.Flashback"
 
 static void
 list_names_cb (TpDBusDaemon *bus_daemon,
@@ -232,18 +227,14 @@ list_names_cb (TpDBusDaemon *bus_daemon,
         GObject *weak_object)
 {
   EmpathyApp *self = (EmpathyApp *) weak_object;
-  guint i;
 
   if (error != NULL)
       goto out;
 
-  for (i = 0; names[i] != NULL; i++)
+  if (g_strv_contains (names, GNOME_SHELL_BUS_NAME) &&
+      !g_strv_contains (names, GNOME_FLASHBACK_BUS_NAME))
     {
-      if (!tp_strdiff (names[i], GNOME_SHELL_BUS_NAME))
-        {
-          self->shell_running = TRUE;
-          break;
-        }
+      self->shell_running = TRUE;
     }
 
 out:
@@ -251,29 +242,13 @@ out:
     {
       DEBUG ("GNOME Shell is running, don't create status icon");
 
-      /* Rely on GNOME Shell to watch session state */
-      empathy_presence_manager_set_auto_away (self->presence_mgr, FALSE);
-
       empathy_roster_window_set_shell_running (
           EMPATHY_ROSTER_WINDOW (self->window), TRUE);
     }
   else
     {
-      gboolean autoaway;
-
       self->icon = empathy_status_icon_new (GTK_WINDOW (self->window),
           self->start_hidden);
-
-      /* Allow Empathy to watch session state */
-      autoaway = g_settings_get_boolean (self->gsettings,
-          EMPATHY_PREFS_AUTOAWAY);
-
-      g_signal_connect (self->gsettings,
-          "changed::" EMPATHY_PREFS_AUTOAWAY,
-          G_CALLBACK (empathy_presence_manager_set_auto_away_cb),
-          self->presence_mgr);
-
-      empathy_presence_manager_set_auto_away (self->presence_mgr, autoaway);
     }
 
   /* Now that we have been started, reset this flag so future invocation will
@@ -290,6 +265,7 @@ empathy_app_activate (GApplication *app)
     {
       GError *error = NULL;
       TpDBusDaemon *dbus;
+      gboolean autoaway;
 
       empathy_gtk_init ();
 
@@ -321,6 +297,21 @@ empathy_app_activate (GApplication *app)
           "<Primary>h",
           "win." EMPATHY_PREFS_UI_SHOW_OFFLINE,
           NULL);
+      gtk_application_add_accelerator (GTK_APPLICATION (app),
+          "<Control>Page_Up", "win.tab-prev", NULL);
+      gtk_application_add_accelerator (GTK_APPLICATION (app),
+          "<Control>Page_Down", "win.tab-next", NULL);
+
+      /* Allow Empathy to watch session state */
+      autoaway = g_settings_get_boolean (self->gsettings,
+          EMPATHY_PREFS_AUTOAWAY);
+
+      g_signal_connect (self->gsettings,
+          "changed::" EMPATHY_PREFS_AUTOAWAY,
+          G_CALLBACK (empathy_presence_manager_set_auto_away_cb),
+          self->presence_mgr);
+
+      empathy_presence_manager_set_auto_away (self->presence_mgr, autoaway);
 
       /* check if Shell is running */
       dbus = tp_dbus_daemon_dup (&error);
@@ -408,11 +399,11 @@ empathy_app_local_command_line (GApplication *app,
   GOptionEntry options[] = {
       { "no-connect", 'n',
         0, G_OPTION_ARG_NONE, &no_connect,
-        N_("Don't connect on startup"),
+        N_("Don’t connect on startup"),
         NULL },
       { "start-hidden", 'h',
         0, G_OPTION_ARG_NONE, &start_hidden,
-        N_("Don't display the contact list or any other dialogs on startup"),
+        N_("Don’t display the contact list or any other dialogs on startup"),
         NULL },
       { "show-preferences", 'p',
         G_OPTION_FLAG_OPTIONAL_ARG, G_OPTION_ARG_CALLBACK, &preferences_cb,
@@ -441,7 +432,7 @@ empathy_app_local_command_line (GApplication *app,
   g_option_group_set_translation_domain (group, GETTEXT_PACKAGE);
   g_option_group_add_entries (group, options);
 
-  optcontext = g_option_context_new (N_("- Empathy IM Client"));
+  optcontext = g_option_context_new (N_("— Empathy IM Client"));
   g_option_context_add_group (optcontext, gtk_get_option_group (FALSE));
   g_option_context_set_main_group (optcontext, group);
   g_option_context_set_translation_domain (optcontext, GETTEXT_PACKAGE);
@@ -840,7 +831,7 @@ main (int argc, char *argv[])
   add_empathy_features ();
 
   app = g_object_new (EMPATHY_TYPE_APP,
-      "application-id", EMPATHY_BUS_NAME,
+      "application-id", EMPATHY_CHAT_BUS_NAME,
       NULL);
 
   retval = g_application_run (G_APPLICATION (app), argc, argv);
